@@ -20,7 +20,7 @@
 
 """Plugin to internationalize MkDocs"""
 
-from copy import copy
+from copy import copy, deepcopy
 
 from mkdocs.config.config_options import Type
 from mkdocs.plugins import BasePlugin
@@ -88,6 +88,29 @@ class I18n(BasePlugin):
                 return page
         return None
 
+    def _get_language_alternate(self, page, pages):
+        language_alternate = []
+        current_lang = self._get_lang(page)
+        languages = copy(self.config.get("languages", {}))
+        if current_lang in languages:
+            languages.pop(current_lang)
+        for lang, lang_name in languages.items():
+            translated_page = self._get_page(page, lang, pages)
+            if translated_page:
+                url = "../" * page.url.count("/")
+                url += translated_page.url
+            else:
+                url = False
+            language_alternate.append(
+                {
+                    "translated_page": translated_page,
+                    "lang": lang,
+                    "lang_name": lang_name,
+                    "url": url,
+                }
+            )
+        return language_alternate
+
     # pylint: disable=unused-argument
     def on_page_markdown(self, markdown, page, config, files):
         """Adds a list of configured languages at the top of page with links
@@ -101,27 +124,24 @@ class I18n(BasePlugin):
         :param files: global files collection
         :return: Markdown source text of page as string
         """
-        current_lang = self._get_lang(page)
         markdown_lang_links = ""
-        languages = copy(self.config.get("languages", {}))
-        if current_lang in languages:
-            languages.pop(current_lang)
-        for lang, lang_name in languages.items():
-            pages = [file.page for file in files.src_paths.values() if file.page]
-            translated_page = self._get_page(page, lang, pages)
-            if translated_page:
-                url = "../" * page.url.count("/")
-                url += translated_page.url
+        pages = [file.page for file in files.src_paths.values() if file.page]
+        for alternate in self._get_language_alternate(page, pages):
+            if alternate.get("translated_page"):
                 markdown_lang_links += (
-                    f"- [{lang_name}]({url})\n"
-                    f"{{: .i18n-link .i18n-link-found .i18n-link-{lang} }}\n"
+                    f"- [{alternate.get('lang_name')}]({alternate.get('url')})\n"
+                    f"{{: .i18n-link .i18n-link-found "
+                    f".i18n-link-{alternate.get('lang')} }}\n"
                 )
             else:
-                no_translation = self.config.get("no_translation", {}).get(lang, "")
+                no_translation = self.config.get("no_translation", {}).get(
+                    alternate.get("lang"), ""
+                )
                 if no_translation:
                     markdown_lang_links += (
-                        f"- {lang_name}: {no_translation}\n"
-                        f"{{: .i18n-link .i18n-link-not-found .i18n-link-{lang} }}\n"
+                        f"- {alternate.get('lang_name')}: {no_translation}\n"
+                        f"{{: .i18n-link .i18n-link-not-found "
+                        f".i18n-link-{alternate.get('lang')} }}\n"
                     )
         return f"{markdown_lang_links}\n\n{markdown}"
 
@@ -153,6 +173,31 @@ class I18n(BasePlugin):
             if subitem.is_section:
                 self._nav_restore(subitem)
 
+    def _customize_extra_alternate(self, context, lang):
+        pages = [file.page for file in context["pages"]]
+        if "alternate_origin" not in context["config"]["extra"]:
+            context["config"]["extra"]["alternate_origin"] = deepcopy(
+                context["config"]["extra"]["alternate"]
+            )
+        context["config"]["extra"]["alternate"] = deepcopy(
+            context["config"]["extra"]["alternate_origin"]
+        )
+        for alternate_config in context["config"]["extra"]["alternate"]:
+            if alternate_config.get("lang") == lang:
+                alternate_config["link"] = context["page"].url
+            else:
+                for alternate in self._get_language_alternate(context["page"], pages):
+                    if alternate.get("translated_page") and alternate.get(
+                        "lang"
+                    ) == alternate_config.get("lang"):
+                        alternate_config.update(
+                            {
+                                "name": alternate.get("lang_name"),
+                                "link": alternate.get("url"),
+                                "lang": alternate.get("lang"),
+                            }
+                        )
+
     def _get_pages_to_remove(self, pages, lang):
         remove = []
         for page in pages:
@@ -210,6 +255,8 @@ class I18n(BasePlugin):
         lang = self._get_lang(page)
         if config["theme"].name == "material":
             context["config"]["theme"].language = lang
+            if "alternate" in context["config"]["extra"]:
+                self._customize_extra_alternate(context, lang)
         remove = self._get_pages_to_remove(nav.pages, lang)
         _remove_nav_pages(nav.pages, remove)
         self._remove_nav_items(nav.items, remove)
